@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2014 WebIssues Team
+* Copyright (C) 2007-2015 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -46,6 +46,13 @@ void ProjectsBatch::renameProject( int projectId, const QString& newName )
     m_queue.addJob( job );
 }
 
+void ProjectsBatch::archiveProject( int projectId )
+{
+    Job job( &ProjectsBatch::archiveProjectJob );
+    job.addArg( projectId );
+    m_queue.addJob( job );
+}
+
 void ProjectsBatch::deleteProject( int projectId, bool force )
 {
     Job job( &ProjectsBatch::deleteProjectJob );
@@ -170,6 +177,20 @@ Command* ProjectsBatch::renameProjectJob( const Job& job )
     return command;
 }
 
+Command* ProjectsBatch::archiveProjectJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "ARCHIVE PROJECT" );
+    command->setArgs( job.args() );
+
+    command->addRule( "OK", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
 Command* ProjectsBatch::deleteProjectJob( const Job& job )
 {
     Command* command = new Command();
