@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2014 WebIssues Team
+* Copyright (C) 2007-2015 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -59,6 +59,12 @@ public:
     */
     void renameProject( int projectId, const QString& newName );
 
+    /**
+    * Add the <tt>ARCHIVE PROJECT</tt> command to the batch. 
+    * @param projectId Identifier of the project to archive.
+    */
+    void archiveProject( int projectId );
+
     /**
     * Add the <tt>DELETE PROJECT</tt> command to the batch. 
     * @param projectId Identifier of the project to delete.
@@ -142,6 +148,7 @@ private:
 private:
     Command* addProjectJob( const Job& job );
     Command* renameProjectJob( const Job& job );
+    Command* archiveProjectJob( const Job& job );
     Command* deleteProjectJob( const Job& job );
 
     Command* addFolderJob( const Job& job );
