@@ -27,6 +27,7 @@
 #include "data/filecache.h"
 #include "data/query.h"
 #include "models/querygenerator.h"
+#include "sqlite/sqlitedriver.h"
 
 #include <QSqlDatabase>
 #include <QFile>
@@ -135,7 +136,7 @@ void DataManager::notifyObservers( UpdateEvent::Unit unit, int id )
 
 bool DataManager::openDatabase()
 {
-    QSqlDatabase database = QSqlDatabase::addDatabase( "SQLITEX" );
+    QSqlDatabase database = QSqlDatabase::addDatabase( new SQLiteDriver() );
 
     database.setDatabaseName( locateCacheFile( "cache.db" ) );
 
