@@ -21,6 +21,7 @@
 
 #include "application.h"
 #include "data/query.h"
+#include "sqlite/sqlitedriver.h"
 
 #include <QFileInfo>
 #include <QFile>
@@ -29,7 +30,7 @@
 FileCache::FileCache( const QString& uuid, const QString& path, QObject* parent ) : QObject( parent ),
     m_uuid( uuid )
 {
-    QSqlDatabase database = QSqlDatabase::addDatabase( "SQLITEX", "FileCache" );
+    QSqlDatabase database = QSqlDatabase::addDatabase( new SQLiteDriver(), "FileCache" );
 
     database.setDatabaseName( path );
 
