@@ -22,9 +22,12 @@
 
 #include <QtCore>
 #include <QtGui>
+#include <QtWidgets>
+#include <QtPrintSupport>
 #include <QtNetwork>
 #include <QtXml>
 #include <QtSql>
 #include <QtWebKit>
+#include <QtWebKitWidgets>
 
 #endif
