@@ -1,6 +1,6 @@
 /****************************************************************************
-* Simple XML-based UI builder for Qt4
-* Copyright (C) 2007-2011 Michał Męciński
+* Simple XML-based UI builder for Qt
+* Copyright (C) 2007-2015 Michał Męciński
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
@@ -108,6 +108,11 @@ public:
     */
     void registerToolStrip( const QString& id, ToolStrip* strip );
 
+    /**
+    * Return the toolstrip with given identifier.
+    */
+    ToolStrip* toolStrip( const QString& id ) const;
+
     /**
     * Supress rebuilding the UI.
     */
